# HCAT 2.0 - Hair Cell Analysis Toolbox GUI

The Hair Cell Analysis Toolbox originally was a collection of software tools for detecting viable hair cells, classifying type, and generating cochleograms automatically. 
Originally shipping with a small graphical user interface, we have vastly improved the capabilities of HCAT with a new GUI. 

This gui comes with an important new feature - the ability to perform automated detection on multi piece dissections!

To find a copy of the new user manual, see here: [User Manual](https://www.dropbox.com/scl/fi/eomc3gujrmm4u4enavjo0/hcat_user_manual.pdf?rlkey=l54z2opwvbovu1tp0i6cmh6ht&dl=1)

### Quickstart Guide:

##### 1. Installation
   1. Create a new conda environment with python 3.11 or greater:
   `conda create -n hcat python=3.11`
   2. Activate the new conda enviornment: `conda activate hcat`
   3. Install hcat with pip: `pip install hcat`
   4. launch hcat with your command line: `hcat`
